<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>LayerCompatibility</name>
    <message>
        <location filename="../LayerCompatibility.js" line="+30"/>
        <source>Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Compatibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Layer 0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Layer 0 behaves like a regular layer (QCAD)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Layer 0 behaves differently (best compatibility)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Entities in blocks on layer 0 take on attributes and visibility of block reference.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
